@@ -1,6 +1,7 @@
 import json
 import os.path
 from collections import defaultdict
+import os
 
 import nltk
 from nltk.stem import WordNetLemmatizer
@@ -11,6 +12,8 @@ nltk.download('punkt')
 nltk.download('wordnet')
 nltk.download("stopwords")
 
+os.system("clear")
+
 class Chatbot:
     def __init__(self, name, lemmatizer=None, stopwords=None, data_file=None):
         self.name = name
